==============
52.0 Pat & Mat
==============

The Avocado team is proud to present another LTS (Long Term Stability)
release: Avocado version 52.0, aka, "Pat & Mat" is now available!

Release documentation: `Avocado 52.0
<http://avocado-framework.readthedocs.io/en/52.0/>`_

LTS Release
===========

For more information on what a LTS release means, please read
:ref:`rfc-long-term-stability`.

For a complete list of changes from the last LTS release to this one,
please refer to :ref:`52.0 LTS <lts_52_0>`.

Changes
=======

The major changes introduced on this version are listed below,
roughly categorized into major topics and intended audience:

Bugfixes
--------

* The job replay option would not work with the ``--execution-order``
  feature, but has now been fixed.

* The ``avocado variants --system-wide`` command is supposed to return
  one variant with the default parameter tree.  This was not functional
  on the last few releases, but has now been fixed.

* The replay of jobs executed with Avocado 36.4 is now possible with
  this release.

Documentation
-------------

A lot of the activity on *this specific* sprint was on documentation.
It includes these new topics:

* A list of all differences that users should pay attention to, from
  the 36.X release to this one.

* The steps to take when migrating from 36.X to 52.0.

* A review guide, with the list of steps to be followed by developers
  when taking a look at Pull Requests.

* The environment in which a test runs (a different process) and its
  peculiarities.

* The interface for the pre/post plugins for both jobs and tests.

Other Changes
-------------

* The HTML reports (generated by an optional plugin) now output a
  single file containing all the resources needed (JS, CSS and
  images).  The original motivation of this change was to let users
  quickly access the HTML when they are stored as test results
  artifacts on servers that compress those files.  With multiple
  files, multiple files had to be decompressed.  If the process wasn't
  automatic (server and client support decompression) this would
  require a tedious process.

* Better examples of YAML files (to be used with the ``yaml_to_mux``
  plugin) have been given.  The other "example" files where really
  files intended to be used by selftests, and having thus been moved
  to the selftests data directory.

For more information, please check out the complete
`Avocado changelog
<https://github.com/avocado-framework/avocado/compare/51.0...52.0>`_.

Release Meeting
===============

The Avocado release meetings are now open to the community via
Hangouts on Air.  The meetings are recorded and made available on the
`Avocado Test Framework YouTube channel
<https://www.youtube.com/channel/UC-RVZ_HFTbEztDM7wNY4NfA>`_.

For this release, you can watch the meeting on `this link
<https://www.youtube.com/watch?v=nTeyu_XgFwM>`_.

----

| Sprint theme: https://trello.com/c/6PuGdjJd/1054-sprint-theme-pat-mat-1976
